/**
 * WordPress dependencies
 */
import { PanelBody, SelectControl, Spinner } from '@wordpress/components';
import { InspectorControls } from "@wordpress/block-editor";
import { useEntityRecords } from '@wordpress/core-data';

/**
 * Internal dependencies
 */
import ArticleSelector from '../../../src/components/article-selector'

/**
 * The edit component
 *
 * @param {{}} props
 * @return {*|string} JSX Element representing the block editor
 */
export default function edit(props) {

	let loading = false
	let post = null

	// Fetch the post if an ID is set
	if (props?.attributes?.id) {
		const fetchPost = useEntityRecords( 'postType', 'post', {include: props.attributes.id} );
		if (fetchPost?.isResolving === true) {
			loading = true;
		} else {
			if (fetchPost?.hasResolved && fetchPost?.records?.[0]) {
				post = fetchPost.records[0];
			}
		}
	}

	return (
		<>
			<InspectorControls>
				<PanelBody
					title="Article Tile"
					initialOpen>
					<ArticleSelector
						onChange={ ( article ) => props.setAttributes( { id: article.id } ) }
					/>
				</PanelBody>
			</InspectorControls>
			{loading &&
				<Spinner />
			}
			{post?.id &&
				<div className="dmg-article-tile">
					{ post?.jetpack_featured_media_url &&
						<img src={ post.jetpack_featured_media_url } />
					}
					<h4>{ post.title.rendered }</h4>
					<p>{ post.excerpt.rendered }</p>
				</div>
			}
		</>
	);
}