<?php

namespace DMG\Tiles\Blocks\Inner_Blocks;

/**
 * Class Tile
 *
 * Abstract class from which to extend tiles
 *
 * @package DMG\Tiles\Inner_Blocks
 */
abstract class Tile {

	/**
	 * Constructor
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_block' ), 11 );
		add_action( 'enqueue_block_editor_assets', array( $this, 'enqueue_block_editor_assets' ) );
	}

	/**
	 * Register the block
	 */
	public function register_block() {
		register_block_type(
			$this->get_dir(),
			array(
				'render_callback' => array( $this, 'render_callback' ),
			)
		);
	}

	/**
	 * Enqueue the block editor assets
	 */
	abstract public function enqueue_block_editor_assets();

	/**
	 * Get the working directory
	 *
	 * @return string The working directory
	 */
	public function get_dir() {
		$ref = new \ReflectionClass( get_class( $this ) );
		
		return dirname( $ref->getFileName() );
	}

	/**
	 * Render a tile
	 *
	 * @param array  $attributes The blocks attributes
	 * @param string $content    Data returned from InnerBlocks.Content
	 * @param array  $block      Block information such as context.
	 * @return string The rendered block markup.
	 */
	public function render_callback( $attributes, $content, $block ) {

		$json = json_decode( file_get_contents( $this->get_dir() . '/block.json' ) );

		/**
		 * Filter the tile container classes
		 *
		 * @param array  $classes   The tile classes
		 * @param string $name      The block name
		 * @param array $attributes The tile attributes
		 */
		$css_classes = apply_filters(
			'dmg_tile_css_classes',
			array(
				'dmg-tile',
				sanitize_title( $json->name )
			),
			$json->name,
			$attributes
		);

		/**
		 * Filter the tile container attributes
		 *
		 * @param array  $html_attributes The tile attributes
		 * @param string $name            The block name
		 * @param array $attributes       The tile attributes
		 */
		$html_attributes = apply_filters(
			'dmg_tile_html_attributes',
			array(),
			$json->name,
			$attributes
		);

		$html_attributes = array_map( fn( $key ) => "{$key}=\"{$html_attributes[ $key ]}\"", array_keys( $html_attributes ) );

		return sprintf(
			'<div class="%s" %s>%s</div>',
			esc_attr( implode( ' ', $css_classes ) ),
			implode( ' ', $html_attributes ),
			$this->content( $attributes, $content, $block )
		);
	}

	/**
	 * Render the inner contents of a tile
	 *
	 * @param array  $attributes The blocks attributes
	 * @param string $content    Data returned from InnerBlocks.Content
	 * @param array  $block      Block information such as context.
	 * @return string The rendered block markup.
	 */
	abstract protected function content( $attributes, $content, $block );

}
