/**
 * WordPress dependencies
 */
import { PanelBody, SelectControl } from '@wordpress/components';
import { InnerBlocks, InspectorControls } from "@wordpress/block-editor";

const ALLOWED_BLOCKS = DMGTiles.allowedBlocks ?? [];

/**
 * Define a custom appender
 */
const appender = () => {

	return (
		<div className="dmg-tile-appender">
			<InnerBlocks.ButtonBlockAppender />
		</div>
	)
}

/**
 * The edit component
 *
 * @param {{}} props
 * @return {*|string} JSX Element representing the block editor
 */
export default function edit(props) {
	
	let classes = [ 'dmg-tiles' ]
	classes.push( `dmg-tiles--${(props.attributes.layout ?? '3-column')}` )

	return (
		<>
			<InspectorControls>
				<PanelBody
					title="DMG Tiles"
					initialOpen>
					<SelectControl
						label="Layout"
						value={ props.attributes.layout }
						options={ [
							{ label: '3 column', value: '3-column' },
							{ label: '4 column', value: '4-column' },
						] }
						onChange={ ( newLayout ) => props.setAttributes( { layout: newLayout } ) }
					/>
				</PanelBody>
			</InspectorControls>
			<div className={ classes.join(' ')}>
				<InnerBlocks
					allowedBlocks={ ALLOWED_BLOCKS }
					orientation="horizontal"
					renderAppender={ appender }
				/>
			</div>
		</>
	);
}